@@ -51,7 +51,7 @@ def getLiveWeatherRSS():
     iconLive = icon [ iconKey ]
     logging.debug('%s = %s' % (iconKey,  iconLive))
     writeLog(mode)
-    return render_template('getLiveWeatherRSS.html', obs = obs, date = date, hr = hr, iconLive = iconLive)
+    return render_template('getLiveWeatherRSS.html', obs = obs, date = date, hr = hr, iconLive = iconLive,  weburl = app.config['QUERY_URL'])
 
 # forecast is called After liveWeather so we will reuse the wdata variable.
 @app.route('/getForecastRSS.aspx', methods=['POST','GET'])
